Worker_DAQ
===================
.. autoclass:: DvG_QDeviceIO.Worker_DAQ
   :members: ,
   :member-order: bysource
   :show-inheritance:

Methods
--------------------

.. automethod:: DvG_QDeviceIO.Worker_DAQ.pause
.. automethod:: DvG_QDeviceIO.Worker_DAQ.unpause
.. automethod:: DvG_QDeviceIO.Worker_DAQ.wake_up